@@ -1,8 +1,4 @@
-import json
-import os
-import pkgutil
 import re
-import time
 
 import requests
 from bs4 import BeautifulSoup
@@ -39,26 +35,11 @@ def fix_name(item_name):
 
 
 # Get price information
-def price_info(item_name):
-    item_name = item_name.replace('&', "and")
-    item_name = item_name.replace(' ', '_').lower()
-
-    time.sleep(0.33)
-
-    url = "https://api.warframe.market/v1/items/" + item_name + "/statistics"
-
-    data = requests.get(url).json()['payload']
-    if 'error' in data:
-        price_data = 'N/A'
+def price_info(item_name, price_data):
+    if item_name in price_data:
+        return int(price_data[item_name][0]['avg_price'])
     else:
-        if '90days' in data['statistics_closed']:
-            price_data = int(data['statistics_closed']['90days'][-1]['avg_price'])
-        elif '48hours' in data['statistics_closed']:
-            price_data = int(data['statistics_closed']['48hours'][-1]['avg_price'])
-        else:
-            price_data = 'N/A'
-
-    return price_data
+        return 'N/A'
 
 
 # Get ducat information
@@ -74,19 +55,12 @@ def ducat_info(item_name, wfcd_api):
 
 
 # Get vaulted status
-def vaulted_info(item_name):
-    url = "https://warframe.fandom.com/wiki/" + item_name
+def vaulted_info(item_name, wfcd_api):
+    if item_name in wfcd_api:
+        if 'vaulted' in wfcd_api[item_name]:
+            return wfcd_api[item_name]['vaulted']
 
-    html = requests.get(url)
-
-    if "/wiki/Category:Vaulted" in html.text:
-        vaulted_status = True
-    elif "Baro Ki'Teer Offering" in html.text:
-        vaulted_status = True
-    else:
-        vaulted_status = False
-
-    return vaulted_status
+    return False
 
 
 # Get category info
@@ -118,93 +92,85 @@ def required_info(item_name, wfcd_api):
     return required
 
 
-def get_relic_list(rebuild=False):
-    if not rebuild:
-        data = pkgutil.get_data(__name__, "relic_list.json")
-        relic_list = json.loads(data)
-        return relic_list
-    else:
-        url = 'https://n8k6e2y6.ssl.hwcdn.net/repos/hnfvc0o3jnfvc873njb03enrf56.html'
+def build_relic_list():
+    url = 'https://n8k6e2y6.ssl.hwcdn.net/repos/hnfvc0o3jnfvc873njb03enrf56.html'
 
-        source = requests.get(url).text
+    source = requests.get(url).text
 
-        soup = BeautifulSoup(source, 'lxml')
+    soup = BeautifulSoup(source, 'lxml')
 
-        tables = soup.find_all('tr',
-                               string=re.compile("Relic .Intact|Relic .Exceptional|Relic .Flawless|Relic .Radiant"))
+    tables = soup.find_all('tr',
+                           string=re.compile("Relic .Intact|Relic .Exceptional|Relic .Flawless|Relic .Radiant"))
 
-        relic_list = {}
+    relic_list = {}
 
-        for table in tables:
-            items = table.find_all_next("tr", limit=6)
+    for table in tables:
+        items = table.find_all_next("tr", limit=6)
 
-            relic = table.find("th").contents[0].split("Relic")[0].rstrip()
-            refinement = table.find("th").contents[0].split("(")[1][0:-1].rstrip()
+        relic = table.find("th").contents[0].split("Relic")[0].rstrip()
+        refinement = table.find("th").contents[0].split("(")[1][0:-1].rstrip()
 
-            x = {'drops': {}}
-            for item in items:
-                item_contents = item.find_all("td")
+        x = {'drops': {}}
+        for item in items:
+            item_contents = item.find_all("td")
 
-                item_name = item_contents[0].contents[0]
-                item_chance = round(float(item_contents[1].contents[0].split("(")[1][0:-2]) / 100, 3)
+            item_name = item_contents[0].contents[0]
+            item_chance = round(float(item_contents[1].contents[0].split("(")[1][0:-2]) / 100, 3)
 
-                if refinement == "Intact":
-                    if item_chance == 0.253:
-                        tier = "Common"
-                        tier_id = 0
-                    elif item_chance == 0.11:
-                        tier = "Uncommon"
-                        tier_id = 1
-                    elif item_chance == 0.02:
-                        tier = "Rare"
-                        tier_id = 2
-                elif refinement == "Exceptional":
-                    if item_chance == 0.233:
-                        tier = "Common"
-                        tier_id = 0
-                    elif item_chance == 0.13:
-                        tier = "Uncommon"
-                        tier_id = 1
-                    elif item_chance == 0.04:
-                        tier = "Rare"
-                        tier_id = 2
-                elif refinement == "Flawless":
-                    if item_chance == 0.2:
-                        tier = "Common"
-                        tier_id = 0
-                    elif item_chance == 0.17:
-                        tier = "Uncommon"
-                        tier_id = 1
-                    elif item_chance == 0.06:
-                        tier = "Rare"
-                        tier_id = 2
-                elif refinement == "Radiant":
-                    if item_chance == 0.167:
-                        tier = "Common"
-                        tier_id = 0
-                    elif item_chance == 0.2:
-                        tier = "Uncommon"
-                        tier_id = 1
-                    elif item_chance == 0.1:
-                        tier = "Rare"
-                        tier_id = 2
+            if refinement == "Intact":
+                if item_chance == 0.253:
+                    tier = "Common"
+                    tier_id = 0
+                elif item_chance == 0.11:
+                    tier = "Uncommon"
+                    tier_id = 1
+                elif item_chance == 0.02:
+                    tier = "Rare"
+                    tier_id = 2
+            elif refinement == "Exceptional":
+                if item_chance == 0.233:
+                    tier = "Common"
+                    tier_id = 0
+                elif item_chance == 0.13:
+                    tier = "Uncommon"
+                    tier_id = 1
+                elif item_chance == 0.04:
+                    tier = "Rare"
+                    tier_id = 2
+            elif refinement == "Flawless":
+                if item_chance == 0.2:
+                    tier = "Common"
+                    tier_id = 0
+                elif item_chance == 0.17:
+                    tier = "Uncommon"
+                    tier_id = 1
+                elif item_chance == 0.06:
+                    tier = "Rare"
+                    tier_id = 2
+            elif refinement == "Radiant":
+                if item_chance == 0.167:
+                    tier = "Common"
+                    tier_id = 0
+                elif item_chance == 0.2:
+                    tier = "Uncommon"
+                    tier_id = 1
+                elif item_chance == 0.1:
+                    tier = "Rare"
+                    tier_id = 2
 
-                x['drops'][item_name] = {'chance': item_chance, 'tier': tier, 'tier_id': tier_id}
+            x['drops'][item_name] = {'chance': item_chance, 'tier': tier, 'tier_id': tier_id}
 
-            relic_drops = dict(sorted(x.items(), key=lambda x: x[1]))
+        relic_drops = dict(sorted(x.items(), key=lambda x: x[1]))
 
-            if relic not in relic_list:
-                relic_list[relic] = {}
+        if relic not in relic_list:
+            relic_list[relic] = {}
 
-            relic_list[relic][refinement] = relic_drops
+        relic_list[relic][refinement] = relic_drops
 
-            vaulted = vaulted_info(relic.replace(" ", "_"))
-            relic_list[relic][refinement]['vaulted'] = vaulted
+    for i in range(0, 5):
+        relic_list.popitem()
 
-        for i in range(0, 5):
-            relic_list.popitem()
-
-        return relic_list
+    return relic_list
 
 
 PAlist = {
@@ -216,7 +182,7 @@ PAlist = {
         "Ember": "Sicarus,Glaive",
         "Equinox": "Stradavar,Tipedo",
         "Frost": "Latron,Reaper",
-        "Gara": "Astilla, Volnus",
+        "Gara": "Astilla,Volnus",
         "Hydroid": "Ballistica,Nami Skyla",
         "Inaros": "Karyst,Panthera",
         "Ivara": "Baza,Aksomati",
@@ -227,6 +193,7 @@ PAlist = {
         "Mirage": "Akbolto,Kogake",
         "Nekros": "Galatine,Tigris",
         "Nezha": "Guandao,Zakti",
+        "Nidus": "Magnus,Strun",
         "Nova": "Soma,Vasto",
         "Nyx": "Hikou,Scindo",
         "Oberon": "Sybaris,Silva & Aegis",
@@ -255,59 +222,54 @@ def access_info(set):
     return PA
 
 
-def get_set_data(rebuild=False):
-    if not rebuild:
-        data = pkgutil.get_data(__name__, "set_data.json")
-        set_data = json.loads(data)
-        return set_data
-    else:
-        # List of prime parts
-        part_list = []
+def build_set_data(relic_list):
+    # List of prime parts
+    part_list = []
 
-        # List of prime sets
-        set_list = []
+    # List of prime sets
+    set_list = []
 
-        relic_list = get_relic_list(True)
-        wfcd_api = get_wfcd_api()
+    wfcd_api = get_wfcd_api()
 
-        for relic in relic_list:
-            for reward in relic_list[relic]['Intact']['drops']:
-                set_name = reward.split("Prime", 1)[0] + "Prime"
+    for relic in relic_list:
+        for reward in relic_list[relic]['Intact']['drops']:
+            set_name = reward.split("Prime", 1)[0] + "Prime"
 
-                if reward != "Forma Blueprint":
-                    if reward not in part_list:
-                        part_list.append(reward)
+            if reward != "Forma Blueprint":
+                if reward not in part_list:
+                    part_list.append(reward)
 
-                    if [set_name] not in set_list and set_name != "Kavasa Prime":
-                        set_list.append([set_name])
+                if [set_name] not in set_list and set_name != "Kavasa Prime":
+                    set_list.append([set_name])
 
-        set_list.append(["Kavasa Prime Kubrow Collar"])
+    set_list.append(["Kavasa Prime Kubrow Collar"])
 
-        # Sorts part_list and set_list alphabetically
-        part_list = sorted(part_list)
-        set_list.sort(key=lambda x: x[0])
+    # Sorts part_list and set_list alphabetically
+    part_list = sorted(part_list)
+    set_list.sort(key=lambda x: x[0])
 
-        set_data = {}
+    set_data = {}
 
-        for i in range(len(set_list)):
-            for j in range(len(part_list)):
-                if set_list[i][0].split()[0] == part_list[j].split()[0]:
-                    set_list[i].append(part_list[j])
+    for i in range(len(set_list)):
+        for j in range(len(part_list)):
+            if set_list[i][0].split()[0] == part_list[j].split()[0]:
+                set_list[i].append(part_list[j])
 
-        for i in range(len(set_list)):
-            parts = {'parts': {}}
-            for j in range(len(set_list[i]) - 1):
-                parts['parts'][set_list[i][j + 1]] = {'plat': price_info(fix_name(set_list[i][j + 1])),
-                                                      'ducats': ducat_info(fix_name(set_list[i][j + 1]), wfcd_api),
-                                                      'required': required_info(fix_name(set_list[i][j + 1]), wfcd_api)}
+    price_data = get_price_data()
 
-            set_data[set_list[i][0]] = parts
-            set_data[set_list[i][0]]['vaulted'] = vaulted_info(set_list[i][0].split("Prime", 1)[0].rstrip() + "_Prime")
-            set_data[set_list[i][0]]['type'] = category_info(set_list[i][0], wfcd_api)
-            set_data[set_list[i][0]]['plat'] = price_info(set_list[i][0] + "_set")
-            set_data[set_list[i][0]]['prime-access'] = access_info(set_list[i][0])
+    for i in range(len(set_list)):
+        parts = {'parts': {}}
+        for j in range(len(set_list[i]) - 1):
+            parts['parts'][set_list[i][j + 1]] = {'plat': price_info(fix_name(set_list[i][j + 1]), price_data),
+                                                  'ducats': ducat_info(fix_name(set_list[i][j + 1]), wfcd_api),
+                                                  'required': required_info(fix_name(set_list[i][j + 1]), wfcd_api)}
+        set_data[set_list[i][0]] = parts
+        set_data[set_list[i][0]]['vaulted'] = vaulted_info(set_list[i][0], wfcd_api)
+        set_data[set_list[i][0]]['type'] = category_info(set_list[i][0], wfcd_api)
+        set_data[set_list[i][0]]['plat'] = price_info(set_list[i][0] + " Set", price_data)
+        set_data[set_list[i][0]]['prime-access'] = access_info(set_list[i][0])
 
-        return set_data
+    return set_data
 
 
 def get_set_name(item_name):
@@ -387,11 +349,18 @@ def get_average_return(relic):
     return relic
 
 
-def update_relic_data(relic_data, set_data):
+never_vaulted = ['Lith C7', 'Meso N11', 'Neo V9', 'Axi S8', 'Axi V10']
+
+
+def build_relic_data(relic_data, set_data):
     for relic in relic_data:
         for refinement in relic_data[relic]:
+            vaulted = False
             for part in relic_data[relic][refinement]['drops']:
                 if "Forma" not in part:
+                    if not vaulted and set_data[get_set_name(part)]['vaulted']:
+                        vaulted = True
+
                     relic_data[relic][refinement]['drops'][part]['price'] = \
                         set_data[get_set_name(part)]['parts'][part]['plat']
 
@@ -410,32 +379,23 @@ def update_relic_data(relic_data, set_data):
                              relic_data[relic][refinement]['drops'][part]['chance'],
                      "1b1": relic_data[relic][refinement]['drops'][part]['price'] *
                             relic_data[relic][refinement]['drops'][part]['chance'] * 4}
+
+            relic_data[relic][refinement]['vaulted'] = vaulted if relic not in never_vaulted else False
             relic_data[relic][refinement]['average_return'] = {}
             relic_data[relic][refinement] = get_average_return(relic_data[relic][refinement])
 
     return relic_data
 
 
-def get_relic_data(rebuild=False):
-    if not rebuild:
-        data = pkgutil.get_data(__name__, "relic_data.json")
-        relic_data = json.loads(data)
-        return relic_data
-    else:
-        relic_data = get_relic_list(True)
-        set_data = get_set_data(True)
-        relic_data = update_relic_data(relic_data, set_data)
+def build_json_files():
+    relic_list = build_relic_list()
+    set_data = build_set_data(relic_list)
+    relic_data = build_relic_data(relic_list, set_data)
 
-    return relic_data
+    return relic_data, set_data
 
 
-def update_prices_and_averages(set_data, relic_data):
-    for prime_set in set_data:
-        set_data[prime_set]['plat'] = price_info(prime_set + "_set")
-
-        for part in set_data[prime_set]['parts']:
-            set_data[prime_set]['parts'][part]['plat'] = price_info(fix_name(part))
-
-    relic_data = update_relic_data(relic_data, set_data)
-
-    return set_data, relic_data
+def get_price_data():
+    soup = BeautifulSoup(requests.get('http://23.95.43.245/history/').text, 'html.parser')
+    return requests.get(sorted(['http://23.95.43.245/history/' + node.get('href')
+                                for node in soup.find_all('a') if node.get('href').endswith('json')])[-1]).json()
